@@ -2,14 +2,14 @@
 **  Copyright (c) 2005-2008 Sendmail, Inc. and its suppliers.
 **    All rights reserved.
 **
-**  Copyright (c) 2009, The OpenDKIM Project.  All rights reserved.
+**  Copyright (c) 2009, 2010, The OpenDKIM Project.  All rights reserved.
 */
 
 #ifndef _DKIM_TYPES_H_
 #define _DKIM_TYPES_H_
 
 #ifndef lint
-static char dkim_types_h_id[] = "@(#)$Id: dkim-types.h,v 1.13.4.2 2010/04/07 19:27:30 cm-msk Exp $";
+static char dkim_types_h_id[] = "@(#)$Id: dkim-types.h,v 1.16 2010/05/04 04:43:04 cm-msk Exp $";
 #endif /* !lint */
 
 #include "build-config.h"
@@ -238,6 +238,7 @@ struct dkim
 	int			dkim_timeout;
 	int			dkim_presult;
 	int			dkim_hdrcnt;
+	int			dkim_minsiglen;
 #ifdef _FFR_RESIGN
 	u_int			dkim_refcnt;
 #endif /* _FFR_RESIGN */
@@ -322,9 +323,9 @@ struct dkim_lib
 	void			(*dkiml_free) (void *closure, void *p);
 #if USE_ARLIB
 	AR_LIB			dkiml_arlib;
-# ifdef _FFR_DNS_UPGRADE
+# ifdef _FFR_DNSUPGRADE
 	AR_LIB			dkiml_arlibtcp;
-# endif /* _FFR_DNS_UPGRADE */
+# endif /* _FFR_DNSUPGRADE */
 #endif /* USE_ARLIB */
 	u_char **		dkiml_senderhdrs;
 	u_char **		dkiml_alwayshdrs;
