@@ -13,7 +13,7 @@ extern "C" {
 #endif /* __cplusplus */
 
 #ifndef lint
-static char dkim_h_id[] = "@(#)$Id: dkim.h,v 1.25.2.2 2010/04/07 19:23:17 cm-msk Exp $";
+static char dkim_h_id[] = "@(#)$Id: dkim.h,v 1.27 2010/05/20 18:39:10 cm-msk Exp $";
 #endif /* !lint */
 
 /* system includes */
@@ -1458,6 +1458,23 @@ extern _Bool dkim_libfeature __P((DKIM_LIB *lib, u_int fc));
 
 extern unsigned long dkim_libversion __P((void));
 
+/*
+**  DKIM_GET_SIGSUBSTRING -- retrieve a minimal signature substring for
+**                           disambiguation
+**
+**  Parameters:
+**  	dkim -- DKIM handle
+**  	sig -- DKIM_SIGINFO handle
+**  	buf -- buffer into which to put the substring
+**  	buflen -- bytes available at "buf"
+**
+**  Return value:
+**  	A DKIM_STAT_* constant.
+*/
+
+extern DKIM_STAT dkim_get_sigsubstring __P((DKIM *, DKIM_SIGINFO *,
+                                            char *, size_t *));
+
 /*
 **  DKIM_TEST_ADSP -- verify that a valid author domain signing policy exists
 **                    in DNS
@@ -1500,6 +1517,28 @@ extern int dkim_test_adsp __P((DKIM_LIB *, const char *, dkim_policy_t *,
 extern int dkim_test_key __P((DKIM_LIB *, char *, char *, char *, size_t,
                               char *, size_t));
 
+/*
+**  DKIM_SIG_GETTAGVALUE -- retrieve a tag's value from a signature or its key
+**
+**  Parameters:
+**  	sig -- DKIM_SIGINFO handle
+**  	keytag -- TRUE iff we want a key's tag
+**  	tag -- name of the tag of interest
+**
+**  Return value:
+**  	Pointer to the string containing the value of the requested key,
+**  	or NULL if not present.
+**
+**  Notes:
+**  	This was added for use in determining whether or not a key or
+**  	signature contained particular data, for gathering general statistics
+**  	about DKIM use.  It is not intended to give applications direct access
+**  	to unprocessed signature or key data.  The data returned has not
+**  	necessarily been vetted in any way.  Caveat emptor.
+*/
+
+extern u_char *dkim_sig_gettagvalue __P((DKIM_SIGINFO *, _Bool, char *));
+
 /*
 **  DKIM_STRLCPY -- size-bounded strcpy()
 **
