@@ -4,14 +4,14 @@
 **
 **  Copyright (c) 2009, 2010, The OpenDKIM Project.  All rights reserved.
 **
-**  $Id: opendkim-db.h,v 1.9 2010/02/20 07:29:59 cm-msk Exp $
+**  $Id: opendkim-db.h,v 1.11.2.2 2010/06/28 18:46:42 cm-msk Exp $
 */
 
 #ifndef _OPENDKIM_DB_H_
 #define _OPENDKIM_DB_H_
 
 #ifndef lint
-static char opendkim_db_h_id[] = "@(#)$Id: opendkim-db.h,v 1.9 2010/02/20 07:29:59 cm-msk Exp $";
+static char opendkim_db_h_id[] = "@(#)$Id: opendkim-db.h,v 1.11.2.2 2010/06/28 18:46:42 cm-msk Exp $";
 #endif /* !lint */
 
 /* system includes */
@@ -32,6 +32,7 @@ static char opendkim_db_h_id[] = "@(#)$Id: opendkim-db.h,v 1.9 2010/02/20 07:29:
 #define DKIMF_DB_TYPE_BDB	3
 #define DKIMF_DB_TYPE_DSN	4
 #define DKIMF_DB_TYPE_LDAP	5
+#define DKIMF_DB_TYPE_LUA	6
 
 #define	DKIMF_LDAP_PARAM_BINDUSER	0
 #define	DKIMF_LDAP_PARAM_BINDPW		1
@@ -68,13 +69,13 @@ typedef struct dkimf_db_data * DKIMF_DBDATA;
 #define	DKIMF_DB_DATA_BINARY	0x01		/* data is binary */
 
 /* prototypes */
-extern void dkimf_db_close __P((DKIMF_DB));
+extern int dkimf_db_close __P((DKIMF_DB));
 extern int dkimf_db_delete __P((DKIMF_DB, void *, size_t));
 extern int dkimf_db_get __P((DKIMF_DB, void *, size_t,
                              DKIMF_DBDATA, unsigned int, _Bool *));
 extern int dkimf_db_mkarray __P((DKIMF_DB, char ***));
 extern int dkimf_db_open __P((DKIMF_DB *, char *, u_int flags,
-                              pthread_mutex_t *));
+                              pthread_mutex_t *, char **));
 extern int dkimf_db_put __P((DKIMF_DB, void *, size_t, void *, size_t));
 extern int dkimf_db_rewalk __P((DKIMF_DB, char *, DKIMF_DBDATA, unsigned int,
                                 void **));
