@@ -4,14 +4,14 @@
 **
 **  Copyright (c) 2009, 2010, The OpenDKIM Project.  All rights reserved.
 **
-**  $Id: opendkim.h,v 1.26 2010/02/23 23:57:16 cm-msk Exp $
+**  $Id: opendkim.h,v 1.28.2.1 2010/07/14 05:12:05 cm-msk Exp $
 */
 
 #ifndef _OPENDKIM_H_
 #define _OPENDKIM_H_
 
 #ifndef lint
-static char opendkim_h_id[] = "@(#)$Id: opendkim.h,v 1.26 2010/02/23 23:57:16 cm-msk Exp $";
+static char opendkim_h_id[] = "@(#)$Id: opendkim.h,v 1.28.2.1 2010/07/14 05:12:05 cm-msk Exp $";
 #endif /* !lint */
 
 #define	DKIMF_PRODUCT	"OpenDKIM Filter"
@@ -49,7 +49,7 @@ static char opendkim_h_id[] = "@(#)$Id: opendkim.h,v 1.26 2010/02/23 23:57:16 cm
 #define	BUFRSZ		1024
 #define	CACHESTATSINT	300
 #define	CBINTERVAL	3
-#define CMDLINEOPTS	"a:Ab:c:C:d:DfF:hi:I:k:lL:m:M:no:p:P:qQrRs:S:t:T:u:U:vVWx:?"
+#define CMDLINEOPTS	"Ab:c:d:DfF:k:lL:no:p:P:qQrs:S:t:T:u:vVWx:?"
 #define	DEFINTERNAL	"csl:127.0.0.1"
 #define	DEFMAXHDRSZ	65536
 #define	DEFTIMEOUT	5
@@ -136,6 +136,7 @@ extern char *dkimf_get_ldap_param __P((int));
 
 #ifdef USE_LUA
 # ifdef DKIMF_LUA_PROTOTYPES
+extern int dkimf_xs_addheader __P((lua_State *));
 extern int dkimf_xs_addrcpt __P((lua_State *));
 extern int dkimf_xs_bodylength __P((lua_State *));
 extern int dkimf_xs_canonlength __P((lua_State *));
