@@ -4,11 +4,11 @@
 **
 **  Copyright (c) 2009, 2010, The OpenDKIM Project.  All rights reserved.
 **
-**  $Id: util.c,v 1.31 2010/02/05 15:36:02 cm-msk Exp $
+**  $Id: util.c,v 1.35.2.3 2010/07/13 18:28:54 cm-msk Exp $
 */
 
 #ifndef lint
-static char util_c_id[] = "@(#)$Id: util.c,v 1.31 2010/02/05 15:36:02 cm-msk Exp $";
+static char util_c_id[] = "@(#)$Id: util.c,v 1.35.2.3 2010/07/13 18:28:54 cm-msk Exp $";
 #endif /* !lint */
 
 #include "build-config.h"
@@ -115,14 +115,18 @@ static char *optlist[] =
 	"_FFR_DKIM_REPUTATION",
 #endif /* _FFR_DKIM_REPUTATION */
 
-#if _FFR_DNS_UPGRADE
-	"_FFR_DNS_UPGRADE",
-#endif /* _FFR_DNS_UPGRADE */
+#if _FFR_DNSUPGRADE
+	"_FFR_DNSUPGRADE",
+#endif /* _FFR_DNSUPGRADE */
 
 #if _FFR_IDENTITY_HEADER
 	"_FFR_IDENTITY_HEADER",
 #endif /* _FFR_IDENTITY_HEADER */
 
+#if _FFR_LDAP_CACHING
+	"_FFR_LDAP_CACHING",
+#endif /* _FFR_IDENTITY_HEADER */
+
 #if _FFR_PARSE_TIME
 	"_FFR_PARSE_TIME",
 #endif /* _FFR_PARSE_TIME */
@@ -182,7 +186,6 @@ struct dkimf_dstring
 /* base64 alphabet */
 static unsigned char alphabet[64] = "ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/";
 
-#ifdef _FFR_REPLACE_RULES
 /*
 **  DKIMF_ISBLANK -- return TRUE iff a string contains only whitespace
 **  
@@ -208,7 +211,6 @@ dkimf_isblank(char *str)
 
 	return TRUE;
 }
-#endif /* _FFR_REPLACE_RULES */
 
 /*
 **  DKIMF_OPTLIST -- print active FFRs
@@ -409,6 +411,8 @@ dkimf_checkip(DKIMF_DB db, struct sockaddr *ip)
 	{
 		int status;
 		int bits;
+		size_t dst_len;
+		char *dst;
 		struct sockaddr_in6 sin6;
 		struct in6_addr addr;
 
@@ -416,47 +420,34 @@ dkimf_checkip(DKIMF_DB db, struct sockaddr *ip)
 
 		memcpy(&addr, &sin6.sin6_addr, sizeof addr);
 
-		if (IN6_IS_ADDR_V4MAPPED(&addr))
-		{
-			inet_ntop(AF_INET,
-			          &addr.s6_addr[INET6_ADDRSTRLEN - INET_ADDRSTRLEN],
-			          ipbuf, sizeof ipbuf);
-		}
-		else
-		{
-			char *dst;
-			size_t dst_len;
+		memset(ipbuf, '\0', sizeof ipbuf);
+		ipbuf[0] = '!';
 
-			memset(ipbuf, '\0', sizeof ipbuf);
-			ipbuf[0] = '!';
+		dst = &ipbuf[1];
+		dst_len = sizeof ipbuf - 1;
 
-			dst = &ipbuf[1];
-			dst_len = sizeof ipbuf - 1;
+		inet_ntop(AF_INET6, &addr, dst, dst_len);
+		dkimf_lowercase(dst);
 
-			inet_ntop(AF_INET6, &addr, dst, dst_len);
+		exists = FALSE;
 
-			exists = FALSE;
+		status = dkimf_db_get(db, ipbuf, 0, NULL, 0, &exists);
+		if (status != 0)
+			return FALSE;
+		if (exists)
+			return FALSE;
 
-			status = dkimf_db_get(db, ipbuf, 0, NULL, 0, &exists);
-			if (status != 0)
-				return FALSE;
-			if (exists)
-				return FALSE;
-
-			status = dkimf_db_get(db, &ipbuf[1], 0, NULL, 0,
-			                      &exists);
-			if (status != 0)
-				return FALSE;
-			if (exists)
-				return TRUE;
-		}
+		status = dkimf_db_get(db, &ipbuf[1], 0, NULL, 0,
+		                      &exists);
+		if (status != 0)
+			return FALSE;
+		if (exists)
+			return TRUE;
 
 		/* iterate over possible bitwise expressions */
 		for (bits = 0; bits <= 128; bits++)
 		{
-			char *dst;
 			size_t sz;
-			size_t dst_len;
 
 			/* try this one */
 			memset(ipbuf, '\0', sizeof ipbuf);
@@ -466,6 +457,7 @@ dkimf_checkip(DKIMF_DB db, struct sockaddr *ip)
 			dst_len = sizeof ipbuf - 1;
 
 			inet_ntop(AF_INET6, &addr, dst, dst_len);
+			dkimf_lowercase(dst);
 
 			sz = strlcat(ipbuf, "/", sizeof ipbuf);
 			if (sz >= sizeof ipbuf)
